@@ -6,11 +6,16 @@
 #functions are in g.loadgame/savegame
 
 from Tkinter import *
+import ImageTk
 import g
 from os import listdir, path, mkdir, remove
 
 #was a game loaded? Used to determine whether to use newgame script.
 did_load = 0
+global cur_button
+cur_button = 0
+
+help_text = StringVar()
 
 #called when "Load" is pressed
 def load_selected():
@@ -29,8 +34,11 @@ def load_selected():
 #give the right action. ("etc", "left", "right", "up", "down", "return")
 def key_handler(switch):
 	if (switch == "esc"): cancel_load()
-	elif (switch == "left"): pass
-	elif (switch == "right"): pass
+	elif (switch == "left" or switch == "right"):
+		global cur_button
+		if cur_button == 0: cur_button = 1
+		else: cur_button = 0
+		refresh_buttons()
 	elif (switch == "up"):
 		if (listbox_saves.size() == 0): return
 		try: item_num = map(int, listbox_saves.curselection())
@@ -51,7 +59,9 @@ def key_handler(switch):
 		else:
 			listbox_saves.select_clear(0, END)
 			listbox_saves.selection_set(0)
-	elif (switch == "return"): load_selected()
+	elif (switch == "return"):
+		if cur_button == 0: load_selected()
+		else: cancel_load()
 
 
 #called when "Cancel" is pressed
@@ -67,6 +77,27 @@ def key_handler_down(event=0): key_handler("down")
 def key_handler_up(event=0): key_handler("up")
 def key_handler_return(event=0): key_handler("return")
 
+def mouse_handler_move(event=0):
+	global cur_button
+	if (event.x < load_scr_button.width()): cur_button = 0
+	else: cur_button = 1
+	refresh_buttons()
+
+def refresh_buttons():
+	canvas_buttons.delete(ALL)
+	if (cur_button == 0):
+		canvas_buttons.create_image(0, 0, anchor=NW,
+			image=load_scr_button_sel, tags="load")
+		help_text.set("Load the game")
+		canvas_buttons.create_image(load_scr_button.width(), 0, anchor=NW,
+			image=leave_button, tags="leave")
+	else:
+		canvas_buttons.create_image(0, 0, anchor=NW,
+			image=load_scr_button, tags="load")
+		canvas_buttons.create_image(load_scr_button.width(), 0, anchor=NW,
+			image=leave_button_sel, tags="leave")
+		help_text.set("Back to main menu")
+
 def init_window_loadgame():
 	#create the window
 	global window_loadgame
@@ -81,20 +112,42 @@ def init_window_loadgame():
 	did_load = 0
 
 	#add the saves listbox
-	global scroll_saves
-	scroll_saves = Scrollbar(window_loadgame)
-	scroll_saves.grid(row=1, column=6, rowspan=10, sticky=NS)
 	global listbox_saves
-	listbox_saves = Listbox(window_loadgame, height=10,
-		yscrollcommand=scroll_saves.set)
+	listbox_saves = Listbox(window_loadgame, height=10)
 	listbox_saves.grid(row=1, column=4, columnspan=2, rowspan=10, sticky=EW)
-	scroll_saves.config(command=listbox_saves.yview)
+	global scroll_saves
+	scroll_saves = Scrollbar(window_loadgame, command=listbox_saves.yview)
+	scroll_saves.grid(row=1, column=5, rowspan=10, sticky="NSE")
+	listbox_saves.config(yscrollcommand=scroll_saves.set)
+
+	global label_help
+	label_help = Label(window_loadgame, textvariable=help_text)
+	label_help.grid(row=0, column=4, columnspan=2, sticky=EW)
+
+	#load images
+	global load_scr_button; global load_scr_button_sel
+	global leave_button; global leave_button_sel
+	load_scr_button = ImageTk.PhotoImage(file=g.mod_directory +
+		"/images/buttons/load_scr.png")
+	load_scr_button_sel = ImageTk.PhotoImage(file=g.mod_directory +
+		"/images/buttons/load_scr_sel.png")
+	leave_button = ImageTk.PhotoImage(file=g.mod_directory +
+		"/images/buttons/leave.png")
+	leave_button_sel = ImageTk.PhotoImage(file=g.mod_directory +
+		"/images/buttons/leave_sel.png")
+
+	#add the canvas
+	global canvas_buttons
+	canvas_buttons = Canvas(window_loadgame, width=load_scr_button.width() +
+		leave_button.width(), height=load_scr_button.height(),
+		highlightthickness=0)
+	canvas_buttons.grid(column=4, row=12, columnspan=3, sticky=N+W)
 
 	#add the buttons
-	button_load = Button(window_loadgame, text="Load",
-		command=load_selected).grid(row=12, column=4)
-	button_cancel = Button(window_loadgame, text="Cancel",
-		command=cancel_load).grid(row=12, column=5)
+#	button_load = Button(window_loadgame, text="Load",
+#		command=load_selected).grid(row=12, column=4)
+#	button_cancel = Button(window_loadgame, text="Cancel",
+#		command=cancel_load).grid(row=12, column=5)
 
 	#If there is no save directory, make one.
 	if path.isdir(g.mod_directory + "/saves") == 0:
@@ -109,6 +162,9 @@ def init_window_loadgame():
 
 	listbox_saves.select_set(0)
 
+	canvas_buttons.bind("<ButtonRelease-1>", key_handler_return)
+	canvas_buttons.bind("<Motion>", mouse_handler_move)
+
 	window_loadgame.bind("<Escape>", key_handler_esc)
 	window_loadgame.bind("<Left>", key_handler_left)
 	window_loadgame.bind("<Right>", key_handler_right)
@@ -116,6 +172,7 @@ def init_window_loadgame():
 	window_loadgame.bind("<Down>", key_handler_down)
 	window_loadgame.bind("<Return>", key_handler_return)
 	listbox_saves.bind("<Double-Button-1>", key_handler_return)
+	refresh_buttons()
 
 	window_loadgame.master.wait_window(window_loadgame)
 	return did_load
