@@ -242,9 +242,9 @@ def findtile(x, y):
 		return returnpix
 	except KeyError:
 		#if the author forgot to define the tile, point out the mistake.
-		print "Tile of " + g.maps[g.zgrid].field[y][x] + " is not defined" \
+		print "Tile of " + g.maps[g.zgrid].field[y][x].name + " is not defined" \
 			+ " in map " + g.maps[g.zgrid].name
-		returnpix.append(g.maps[g.zgrid].tiles["a"].pix)
+		returnpix.append(g.maps[g.zgrid].field[0][0].pix)
 		return returnpix
 
 
