@@ -523,6 +523,8 @@ def do_load_map():
 #given input and output maps, copies the important parts.
 def copy_map(output_map, input_map):
 	output_map.name = input_map.name
+	global map_name
+	map_name = output_map.name
 	for y in range(len(input_map.field)):
 		output_map.field.append([])
 		for x in range(len(input_map.field[y])):
