@@ -95,12 +95,13 @@ def reset_vars():
 	timestep = 0
 	cur_mon_hp = 0
 	g.var_list = {}
+	g.item.dropped_items = []
 
 	#clear the inventory
-	for i in range(len(g.inv)):
-		g.inv[i]= -1
-	for i in range(len(g.equip)):
-		g.equip[i]= -1
+	for i in range(len(g.item.inv)):
+		g.item.inv[i]= -1
+	for i in range(len(g.item.equip)):
+		g.item.equip[i]= -1
 	#clear skills
 	for i in range(len(g.skill)):
 		g.skill[i][5] = 0
@@ -120,6 +121,9 @@ def get_stats():
 
 #Use the stats given to create a new character.
 def begin_game():
+	g.read_maps()
+	g.item.load_dropped_items()
+
 	#just in case someone changed the name
 	#after rerolling or loading
 	g.name = name.get()
